@@ -3,7 +3,7 @@ from typing import List, Optional
 from pydantic import BaseModel, Field, root_validator
 
 from .extensions import Extensions
-from .shared import ExtensionTypes, Link
+from .shared import Link
 from .version import STAC_VERSION
 
 
@@ -16,7 +16,7 @@ class Catalog(BaseModel):
     description: str
     stac_version: str = Field(STAC_VERSION, const=True)
     links: List[Link]
-    stac_extensions: Optional[List[ExtensionTypes]]
+    stac_extensions: Optional[List[str]]
     title: Optional[str]
 
     class Config:
